@@ -1,5 +1,21 @@
 /*
- * Copyright (c) 2006-2014 LxDE Developers, see the file AUTHORS for details.
+ * Copyright (C) 2006-2010 Hong Jen Yee (PCMan) <pcman.tw@gmail.com>
+ *               2006-2008 Jim Huang <jserv.tw@gmail.com>
+ *               2008 Fred Chien <fred@lxde.org>
+ *               2009 Jürgen Hötzel <juergen@archlinux.org>
+ *               2009-2010 Marty Jack <martyj19@comcast.net>
+ *               2010 Lajos Kamocsay <lajos@panka.com>
+ *               2012 Piotr Sipika <Piotr.Sipika@gmail.com>
+ *               2012-2013 Henry Gebhardt <hsggebhardt@gmail.com>
+ *               2012 Jack Chen <speed.up08311990@gmail.com>
+ *               2012 Rafał Mużyło <galtgendo@gmail.com>
+ *               2012 Michael Rawson <michaelrawson76@gmail.com>
+ *               2012 Julien Lavergne <julien.lavergne@gmail.com>
+ *               2013 Rouslan <rouslan-k@users.sourceforge.net>
+ *               2013 peadaredwards <peadaredwards@users.sourceforge.net>
+ *               2014-2015 Andriy Grytsenko <andrej@rep.kiev.ua>
+ *
+ * This file is a part of LXPanel project.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1629,6 +1645,12 @@ void panel_set_panel_configuration_changed(Panel *p)
     _panel_set_panel_configuration_changed(p->topgwin);
 }
 
+static inline void _update_orientation(Panel *p)
+{
+    p->orientation = (p->edge == EDGE_TOP || p->edge == EDGE_BOTTOM)
+                        ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL;
+}
+
 static gboolean _panel_idle_reconfigure(gpointer widget)
 {
     LXPanel *panel;
@@ -1642,15 +1664,13 @@ static gboolean _panel_idle_reconfigure(gpointer widget)
     panel = LXPANEL(widget);
     p = panel->priv;
     previous_orientation = p->orientation;
-    p->orientation = (p->edge == EDGE_TOP || p->edge == EDGE_BOTTOM)
-        ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL;
+    _update_orientation(p);
 
     /* either first run or orientation was changed */
-    if (!p->initialized || previous_orientation != p->orientation)
+    if (previous_orientation != p->orientation)
     {
         panel_adjust_geometry_terminology(p);
-        if (p->initialized)
-            p->height = ((p->orientation == GTK_ORIENTATION_HORIZONTAL) ? PANEL_HEIGHT_DEFAULT : PANEL_WIDTH_DEFAULT);
+        p->height = ((p->orientation == GTK_ORIENTATION_HORIZONTAL) ? PANEL_HEIGHT_DEFAULT : PANEL_WIDTH_DEFAULT);
         if (p->height_control != NULL)
             gtk_spin_button_set_value(GTK_SPIN_BUTTON(p->height_control), p->height);
         if ((p->widthtype == WIDTH_PIXEL) && (p->width_control != NULL))
@@ -1775,6 +1795,7 @@ panel_parse_global(Panel *p, config_setting_t *cfg)
         p->background_file = g_strdup(str);
     config_setting_lookup_int(cfg, "iconsize", &p->icon_size);
 
+    _update_orientation(p);
     panel_normalize_configuration(p);
 
     return 1;
